==> qtjambi-qt3dinput-6.6.0-sources.jar: io/qt/qt3d/input/QInputSettings.java <==
package io.qt.qt3d.input;

import io.qt.*;


/**
 * <p>Holds the pointer to an input event source object</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3dinput-qinputsettings.html">Qt3DInput::QInputSettings</a></code></p>
 */
public class QInputSettings extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @QtPropertyMember(enabled=false)
    private Object __rcEventSource = null;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QInputSettings.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3dinput-qinputsettings.html#eventSource-prop">Qt3DInput::QInputSettings::<wbr>eventSourceChanged(QObject*)</a></code></p>
     */
    @QtPropertyNotify(name="eventSource")
    public final @NonNull Signal1<io.qt.core.@Nullable QObject> eventSourceChanged = new Signal1<>();
    
    /**
     * <p>See <code>Qt3DInput::QInputSettings::<wbr>QInputSettings(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QInputSettings(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QInputSettings instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3dinput-qinputsettings.html#eventSource-prop">Qt3DInput::QInputSettings::<wbr>eventSource()const</a></code></p>
     */
    @QtPropertyReader(name="eventSource")
    @QtUninvokable
    public final io.qt.core.@Nullable QObject eventSource(){
        return eventSource_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QObject eventSource_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3dinput-qinputsettings.html#eventSource-prop">Qt3DInput::QInputSettings::<wbr>setEventSource(QObject*)</a></code></p>
     */
    @QtPropertyWriter(name="eventSource")
    public final void setEventSource(io.qt.core.@Nullable QObject eventSource){
        setEventSource_native_QObject_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(eventSource));
        __rcEventSource = eventSource;
    }
    
    private native void setEventSource_native_QObject_ptr(long __this__nativeId, long eventSource);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QInputSettings(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QInputSettings(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QInputSettings instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QInputSettings(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QInputSettings() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #eventSource()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@Nullable QObject getEventSource() {
        return eventSource();
    }
}

==> qtjambi-qt3dinput-6.6.2-sources.jar: io/qt/qt3d/input/QInputSettings.java <==
package io.qt.qt3d.input;

import io.qt.*;


/**
 * <p>Holds the pointer to an input event source object</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3dinput-qinputsettings.html">Qt3DInput::QInputSettings</a></code></p>
 */
public class QInputSettings extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @QtPropertyMember(enabled=false)
    private Object __rcEventSource = null;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QInputSettings.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3dinput-qinputsettings.html#eventSource-prop">Qt3DInput::QInputSettings::<wbr/>eventSourceChanged(QObject*)</a></code></p>
     */
    @QtPropertyNotify(name="eventSource")
    public final @NonNull Signal1<io.qt.core.@Nullable QObject> eventSourceChanged = new Signal1<>();
    
    /**
     * <p>See <code>Qt3DInput::QInputSettings::<wbr/>QInputSettings(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QInputSettings(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QInputSettings instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3dinput-qinputsettings.html#eventSource-prop">Qt3DInput::QInputSettings::<wbr/>eventSource()const</a></code></p>
     */
    @QtPropertyReader(name="eventSource")
    @QtUninvokable
    public final io.qt.core.@Nullable QObject eventSource(){
        return eventSource_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QObject eventSource_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3dinput-qinputsettings.html#eventSource-prop">Qt3DInput::QInputSettings::<wbr/>setEventSource(QObject*)</a></code></p>
     */
    @QtPropertyWriter(name="eventSource")
    public final void setEventSource(io.qt.core.@Nullable QObject eventSource){
        setEventSource_native_QObject_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(eventSource));
        __rcEventSource = eventSource;
    }
    
    private native void setEventSource_native_QObject_ptr(long __this__nativeId, long eventSource);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QInputSettings(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QInputSettings(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QInputSettings instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QInputSettings(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QInputSettings() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #eventSource()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@Nullable QObject getEventSource() {
        return eventSource();
    }
}
